diff mx/mx_graal.py @ 21551:5324104ac4f3

moved com.oracle.graal.hotspot.jvmci classes to com.oracle.jvmci.hotspot module (JBS:GRAAL-53)
author Doug Simon <doug.simon@oracle.com>
date Tue, 26 May 2015 17:13:37 +0200
parents ca14581fadc4
children b1530a6cce8c
line wrap: on
line diff
--- a/mx/mx_graal.py	Tue May 26 12:27:05 2015 +0200
+++ b/mx/mx_graal.py	Tue May 26 17:13:37 2015 +0200
@@ -513,9 +513,9 @@
 def _makeHotspotGeneratedSourcesDir():
     """
     Gets the directory containing all the HotSpot sources generated from
     Graal Java sources. This directory will be created if it doesn't yet exist.
     """
-    hsSrcGenDir = join(mx.project('com.oracle.graal.hotspot').source_gen_dir(), 'hotspot')
+    hsSrcGenDir = join(mx.project('com.oracle.jvmci.hotspot').source_gen_dir(), 'hotspot')
     if not exists(hsSrcGenDir):
         os.makedirs(hsSrcGenDir)
     return hsSrcGenDir
@@ -557,7 +557,7 @@
         mx.update_file(graalRuntime_inline_hpp, tmp.getvalue())
 
         # Store SHA1 in generated Java class and append class to specified jar
-        javaPackageName = 'com.oracle.graal.hotspot.sourcegen'
+        javaPackageName = 'com.oracle.jvmci.hotspot.sourcegen'
         javaClassName = javaPackageName + '.GeneratedSourcesSha1'
         javaSource = join(_graal_home, 'GeneratedSourcesSha1.java')
         javaClass = join(_graal_home, javaClassName.replace('.', os.path.sep) + '.class')
@@ -513,9 +513,9 @@
     """
     Gets the directory containing all the HotSpot sources generated from
-    Graal Java sources. This directory will be created if it doesn't yet exist.
+    JVMCI Java sources. This directory will be created if it doesn't yet exist.
     """